from .teomim import teomim


"""                                                                                                                        
# teomim                                                                                                                   
                                                                                                                           
Description:                                                                                                               
    Digital twin for human disease risk. Generate realistic diagnostic histories for ptients nearly indistinguishable from real population using deep comorbidity signatures.                                                                  
                                                                                                                           
---                                                                                                                        
                                                                                                                           
Installation:                                                                                                              
   ```                                                                                                                     
      pip install teomim                                                                                                   
   ```                                                                                                                                                                                                      
Notes:                                                                                                                     
   Models are contextual

"""



from quasinet.qnet import load_qnet

def gentrees(modelpath,OUTDIR='trees/',format='png',threshold=1):
    model=load_qnet(modelpath,gz=False)
    model.viz_trees(tree_path=OUTDIR,
                    big_enough_threshold=threshold,format=format)
